@@ -13,12 +13,7 @@ OC.L10N.register(
     "Settings" : "Կարգավորումներ",
     "Rename" : "Վերանվանել",
     "Delete" : "հեռացնել",
-    "Refresh" : "Թարմացնել",
-    "Description" : "Նկարագրություն",
     "Folder" : "Պանակ",
-    "Create" : "Ստեղծել",
-    "Import" : "Ներմուծում",
-    "Export" : "Արտահանում",
-    "Help" : "Օգնություն"
+    "Refresh" : "Թարմացնել"
 },
 "nplurals=2; plural=(n != 1);");
