@@ -29,13 +29,12 @@ OC.L10N.register(
     "Rename Feed" : "Đổi tên nguồn dữ liệu",
     "Newest first" : "Mới trước",
     "Oldest first" : "Cũ trước",
-    "Previous" : "Trước",
-    "Next" : "Tiếp theo",
     "Mark unread" : "Đánh dấu là chưa đọc",
     "by" : "bởi",
     "Open website" : "Mở trang web",
-    "Not available" : "Không khả dụng",
     "Title" : "Tên",
+    "Folder" : "Thư mục",
+    "Not available" : "Không khả dụng",
     "Keyboard shortcut" : "Phím tắt",
     "Action" : "Hành động",
     "right" : "phải",
